Ocyan plugin Oscar Checkout 
===========================

Installation
------------
Add `ocyan.plugin.oscar_checkout` to your projects dependencies.

Usage
-----
The Oscar checkout plugin makes changes to the Oscar checkout page so that it creates a onestepcheckout. The onstepcheckout can consist of the following fields: 
* voucher/promo code form
* email address 
* radio buttons for (1) new customer as guest, (2) create account for new customer or (3) existing customer
* shipping address 
* optional billing address (other than shipping address)
* payment methods
* optional comments
* order details
* checkbox for terms and conditions
* checkbox for newsletter registration
* place order button

Customization
-------------
Change the OSCAR_REQUIRED_ADDRESS_FIELDS to change the required address fields
Change the OSCARAPI_USERADDRESS_FIELDS setting to remove/add fields
Change the OSCAR_SHIPPING_FORM_FIELD_ORDER to change the order of fields
Change the OSCAR_SHIPPING_FORM_FIELDS setting to remove/add fields
Change the OSCAR_BILLING_FORM_FIELDS to remove/add the billing address form fields  
Change the OSCAR_BILLING_FORM_FIELD_ORDER to change the order of the billing address fields 

Configuration
-------------
The following setting can be configured:
* show_voucher_block: Show the voucher block on the checkoutpage (onestep.html).

For example: 

```json
    "oscar_checkout": {
      "show_voucher_block": true
    },
```
